<?php

/**
 * @file
 * Describe hooks provided by the Moderation module.
 */

/**
 * This hool allows you to interact with the action, before the rule is
 * triggered. This could be usefull to log the entity before it's changed or to
 * manipulate the event or even the entity.
 *
 * @param $event
 *   An event key like node_publish_action.
 * @param $entity_type
 *   The entity type of the moderated entity.
 * @param $entity_id
 *   The entity id of the moderated entity.
 */
function hook_moderation_preaction($event, $entity_type, $entity_id) {

}

/**
 * This hook makes it possible to add actions to moderation. The associative
 * array key should be the entity type, the action will be available for.
 *
 * @see node.action.inc for some simple examples.
 * @see moderation.action.inc for a more complex example with custom label
 *      callback
 * 
 * @return array
 */
function hook_moderation_action_info() {
  $actions = array();
  // Key is the entity this action will be available for.
  $actions['node'] = array(
    // Action key.
    'node_publish_action' => array(
      // Rules event to trigger. If the rule doesn't exists, it will be
      // generated by the data defined in action.
      'event' => 'moderation_publish',
      // The data used to set the label. Alternative a custom label callback can
      // be defined.
      'label data' => array(
        'data' => 'status',
        'labels' => array(
          0 => t('publish'),
          1 => t('unpublish'),
        ),
      ),
      // Optional action to generate a rule. This methode can be used for every
      // entity property.
      'action' => array(
        'if' => array(
          'data' => array(
            'status',
            1,
          ),
          'do' => array(
            'status',
            0,
          ),
        ),
        'else if' => array(
          'data' => array(
            'status',
            0,
          ),
          'do' => array(
            'status',
            1,
          ),
        ),
      ),
    ),
  );
  return $actions;
}
